/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, Input, OnInit } from "@angular/core";
import { CapabilityRequest } from "../../../../model/capability-request";
import { CapabilityRequestService } from "../../../../services/capability-request.service";
import { CapabilityVersion } from "../../../../model/capability-version";
import * as dayjs from 'dayjs';
import * as relativeTime from 'dayjs/plugin/relativeTime';
import * as localizedFormat from 'dayjs/plugin/localizedFormat';
import {Capability} from "../../../../model/capability";
@Component({
  selector: "app-request-header",
  templateUrl: "./request-header.component.html",
  styleUrls: ["./request-header.component.scss"],
})
export class RequestHeaderComponent implements OnInit {
  @Input() capability: Capability;
  @Input() capabilityRequest: CapabilityRequest;
  @Input() latestVersion: CapabilityVersion;
  createdAt;
  updatedAt;

  constructor(private capabilityRequestService: CapabilityRequestService,) {}

  ngOnInit(): void {
    this.createdAt = this.formatDate(this.capabilityRequest.created_at)
    this.updatedAt = this.formatDate(this.capabilityRequest.updated_at)
  }

  private formatDate(date): string {
    dayjs.extend(relativeTime)
    dayjs.extend(localizedFormat)

    var dateFromNow = dayjs(date).fromNow()
    var afterOneWeekDisplay = dateFromNow + " on " + dayjs(date).format('llll');
    return this.isOlderThanOneWeek(date) ? afterOneWeekDisplay : dateFromNow;
  }

  private isOlderThanOneWeek(date): boolean {
    const now = dayjs();
    date = dayjs(date)
    return now.diff(date, "week") ? true : false
  }

  public cancelRequestObserver = {
    next: () => {
      window.location.reload();
    },
    error: (error) => {
      console.log(error);
    },
  };

  cancelRequest(requestId: string, versionId: number) {
    this.capabilityRequestService
      .cancelRequest(requestId, versionId.toString())
      .subscribe(this.cancelRequestObserver);
  }

  isCancellable(): boolean {
    return !(
      this.latestVersion && (
          this.latestVersion.state !== 'Cancelled' &&
          this.latestVersion.state !== 'Complete' &&
          this.latestVersion.state !== 'Failed' &&
          this.latestVersion.state !== 'Error'
        )
      )
  }
}
