/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Injectable } from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {Observable} from "rxjs";

@Injectable({
  providedIn: 'root'
})
export class WorkflowService {
  private endpoint = "workflows/";

  constructor(private httpClient: HttpClient) { }

  // Retrieve the contents of qa_notes.html for a given job
  retrieveQaNotes(workflowName: string, requestID: string): Observable<string> {
    const url = this.endpoint + workflowName + "/requests/" + requestID + "/qa_notes";
    return this.httpClient.get<any>(url);
  }

  saveQaNotes(workflowName: string, requestID: string, edits: string): Observable<string> {
    const url = this.endpoint + workflowName + "/requests/" + requestID + "/qa_notes";
    return this.httpClient.post<any>(url, JSON.stringify({"edits":edits}));
  }

  abortWorkflow(requestID: string): Observable<string> {
    const url = this.endpoint + "requests/" + requestID + "/abort";
    return this.httpClient.post(url, JSON.stringify({"workflow_req_id": requestID}), {responseType: 'text'});
  }
}
