# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add CAPO_PATH env var to download and calibration

Revision ID: c4001510507c
Revises: 2b6e18877c8e
Create Date: 2021-05-21 10:02:03.013963

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "c4001510507c"
down_revision = "2b6e18877c8e"
branch_labels = None
depends_on = None


def upgrade():
    submit_file_content = """executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = test_download.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/deliver

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{submit_file_content}' "
        "WHERE filename = 'test_download.condor'"
    )

    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )


def downgrade():
    submit_file_content = """executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = test_download.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/deliver

getenv = True

queue
"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{submit_file_content}' "
        "WHERE filename = 'test_download.condor'"
    )

    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh

getenv = True

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )
